package com.jiuqi.grid;

import com.jiuqi.util.StringUtils;
import com.jiuqi.util.chinese.ChineseDouble;
import java.io.Serializable;
import java.text.DecimalFormat;

/* loaded from: com_jiuqi_grid.jar:com/jiuqi/grid/NumberCellProperty.class */
public class NumberCellProperty implements NumberCellPropertyIntf, CellDataProcessorIntf, Serializable {
    protected CellDataPropertyIntf cellDataProperty;

    public NumberCellProperty(CellDataPropertyIntf dataProperty) {
        this.cellDataProperty = dataProperty;
    }

    public NumberCellProperty(GridCell cell) {
        this(new CellDataProperty(cell));
    }

    public CellDataPropertyIntf getCellDataProperty() {
        return this.cellDataProperty;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public int getDecimal() {
        return this.cellDataProperty.getDataFlag();
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setDecimal(int value) {
        if (value <= 15) {
            if (value < 0) {
                value = 0;
            }
            this.cellDataProperty.setDataFlag((byte) value);
            return;
        }
        throw new IllegalArgumentException("错误设置了数字的小数位数，应该在0-15之间！");
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public int getPrecision() {
        return this.cellDataProperty.getDataProperty() & 31;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setPrecision(int value) {
        if (value >= 0 && value <= 32) {
            int data = value & 31;
            this.cellDataProperty.setDataProPerty((short) ((this.cellDataProperty.getDataProperty() & (-32)) | data));
            return;
        }
        throw new IllegalArgumentException("错误设置了数字的精度，应该在0-32之间！");
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public boolean getThoundsMark() {
        return (this.cellDataProperty.getDataProperty() & 32768) != 0;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setThoundsMarks(boolean value) {
        if (value) {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 32768));
        } else {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-32769)));
        }
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public boolean getBracketNegative() {
        return (this.cellDataProperty.getDataProperty() & 16384) != 0;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setBracketNegative(boolean value) {
        if (value) {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 16384));
        } else {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-16385)));
        }
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public boolean getWarningNegative() {
        return (this.cellDataProperty.getDataProperty() & 8192) != 0;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setWarningNegative(boolean value) {
        if (value) {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 8192));
        } else {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-8193)));
        }
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public boolean getChineseNumber() {
        return (this.cellDataProperty.getDataProperty() & 4096) != 0;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setChineseNumber(boolean value) {
        if (value) {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 4096));
        } else {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-4097)));
        }
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public boolean getBigChineseChar() {
        return (this.cellDataProperty.getDataProperty() & 2048) != 0;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setBigChineseChar(boolean value) {
        if (value) {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 2048));
        } else {
            this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-2049)));
        }
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public boolean getIsPercent() {
        return this.cellDataProperty.getDataType() == 2 && (this.cellDataProperty.getDataProperty() & 1024) != 0;
    }

    @Override // com.jiuqi.grid.NumberCellPropertyIntf
    public void setIsPercent(boolean value) {
        if (this.cellDataProperty.getDataType() == 2) {
            if (value) {
                this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 1024));
            } else {
                this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-1025)));
            }
        }
    }

    @Override // com.jiuqi.grid.CellDataProcessorIntf
    public String getEditText(String storeText) {
        return storeText;
    }

    public String getShowText(String storeText) {
        if (storeText != null) {
            String showText = null;
            if (storeText == "") {
                showText = "";
            } else {
                String storeText2 = StringUtils.eliminate(storeText, ',');
                try {
                    double value = Double.parseDouble(storeText2);
                    boolean isNegtive = value < 0.0d;
                    boolean isPercent = getIsPercent();
                    boolean showThoundsMark = getThoundsMark();
                    if (isNegtive) {
                        value = -value;
                    }
                    if (isPercent && !showThoundsMark) {
                        value *= 100.0d;
                        setDecimal(getDecimal() - 2);
                    } else if (isPercent && showThoundsMark) {
                        value *= 1000.0d;
                        setDecimal(getDecimal() - 3);
                    }
                    int decimal = getDecimal();
                    if (decimal == 15) {
                    }
                    double value2 = trimDouble(value, getDecimal());
                    if (!getChineseNumber()) {
                        showText = formatNumberString(value2, getDecimal(), getThoundsMark());
                        if (isPercent && !showThoundsMark) {
                            showText = String.valueOf(showText) + "%";
                        }
                        if (isPercent && showThoundsMark) {
                            showText = String.valueOf(showText) + "‰";
                        }
                        if (isNegtive) {
                            if (getBracketNegative()) {
                                showText = "(" + showText + ")";
                            } else {
                                showText = "-" + showText;
                            }
                        }
                    } else {
                        if (isPercent && !showThoundsMark) {
                            showText = new ChineseDouble(value2 / 100.0d).getPercentForm(getDecimal(), true, getBigChineseChar());
                        }
                        if (isPercent && showThoundsMark) {
                            showText = new ChineseDouble(value2 / 1000.0d).getPermillageForm(getDecimal(), true, getBigChineseChar());
                        }
                        if (!isPercent) {
                            ChineseDouble cnDouble = new ChineseDouble(value2);
                            if (!showThoundsMark) {
                                showText = cnDouble.chineseValue(getDecimal(), false, getBigChineseChar());
                            } else {
                                showText = cnDouble.chineseValue(getDecimal(), true, getBigChineseChar());
                            }
                        }
                        if (isNegtive) {
                            showText = "（负）" + showText;
                        }
                    }
                    if (isPercent) {
                        setDecimal(getDecimal() + (showThoundsMark ? 3 : 2));
                    }
                } catch (NumberFormatException unused) {
                    return storeText2;
                }
            }
            return showText;
        }
        throw new IllegalArgumentException("不能解析指向null的字符串为数字！");
    }

    @Override // com.jiuqi.grid.CellDataProcessorIntf
    public String parseEditText(String editText) {
        double value = Double.parseDouble(editText);
        return formatNumberString(value, getDecimal(), false);
    }

    public String parseShowText(String showText) {
        String value;
        if (!getChineseNumber()) {
            value = showText;
        } else {
            try {
                value = ChineseDouble.valueOf(showText);
            } catch (Exception unused) {
                throw new IllegalArgumentException("中文数值有错误，解析失败");
            }
        }
        double dbValue = Double.parseDouble(value);
        return formatNumberString(dbValue, getDecimal(), getThoundsMark());
    }

    private static double trimDouble(double source, int frcLength) {
        if (frcLength < 0) {
            frcLength = 0;
        }
        int multiplier = (int) Math.exp(Math.log(10.0d) * frcLength);
        double temp = Math.round(source * multiplier);
        double des = temp / multiplier;
        return des;
    }

    private static String formatNumberString(double value, int decimal, boolean thoundsMark) {
        DecimalFormat df = new DecimalFormat();
        df.setGroupingUsed(false);
        if (thoundsMark) {
            df.setGroupingSize(3);
            df.setGroupingUsed(true);
        }
        if (decimal >= 0) {
            df.setMaximumFractionDigits(decimal);
            df.setMinimumFractionDigits(decimal);
        }
        return df.format(value);
    }
}
